# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKDisplacementFieldPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkTimeVaryingBSplineVelocityFieldTransformPython
else:
    import _itkTimeVaryingBSplineVelocityFieldTransformPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkFixedArrayPython
import itk.itkSizePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.ITKCommonBasePython
import itk.itkImageRegionPython
import itk.itkArrayPython
import itk.itkVelocityFieldTransformPython
import itk.itkDisplacementFieldTransformPython
import itk.itkArray2DPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkTransformBasePython
import itk.itkOptimizerParametersPython
import itk.itkDiffusionTensor3DPython

def itkTimeVaryingBSplineVelocityFieldTransformD2_New():
    return itkTimeVaryingBSplineVelocityFieldTransformD2.New()

class itkTimeVaryingBSplineVelocityFieldTransformD2(itk.itkVelocityFieldTransformPython.itkVelocityFieldTransformD2):
    r"""Proxy of C++ itkTimeVaryingBSplineVelocityFieldTransformD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTimeVaryingBSplineVelocityFieldTransformD2_Pointer"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTimeVaryingBSplineVelocityFieldTransformD2_Pointer"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_Clone(self)

    def GetTimeVaryingVelocityFieldControlPointLattice(self):
        r"""GetTimeVaryingVelocityFieldControlPointLattice(self) -> itkImageVD23"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_GetTimeVaryingVelocityFieldControlPointLattice(self)

    def SetTimeVaryingVelocityFieldControlPointLattice(self, fieldLattice):
        r"""
        SetTimeVaryingVelocityFieldControlPointLattice(self, fieldLattice)

        Parameters
        ----------
        fieldLattice: itkImageVD23 *

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_SetTimeVaryingVelocityFieldControlPointLattice(self, fieldLattice)

    def UpdateTransformParameters(self, update, factor=1.):
        r"""
        UpdateTransformParameters(self, update, factor=1.)

        Parameters
        ----------
        update: itkArrayD const &
        factor: double

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_UpdateTransformParameters(self, update, factor)

    def SetVelocityFieldOrigin(self, _arg):
        r"""
        SetVelocityFieldOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD3

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_SetVelocityFieldOrigin(self, _arg)

    def GetVelocityFieldOrigin(self):
        r"""GetVelocityFieldOrigin(self) -> itkPointD3"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_GetVelocityFieldOrigin(self)

    def SetVelocityFieldSpacing(self, _arg):
        r"""
        SetVelocityFieldSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD3

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_SetVelocityFieldSpacing(self, _arg)

    def GetVelocityFieldSpacing(self):
        r"""GetVelocityFieldSpacing(self) -> itkVectorD3"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_GetVelocityFieldSpacing(self)

    def SetVelocityFieldSize(self, _arg):
        r"""
        SetVelocityFieldSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize3

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_SetVelocityFieldSize(self, _arg)

    def GetVelocityFieldSize(self):
        r"""GetVelocityFieldSize(self) -> itkSize3"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_GetVelocityFieldSize(self)

    def SetVelocityFieldDirection(self, _arg):
        r"""
        SetVelocityFieldDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD33

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_SetVelocityFieldDirection(self, _arg)

    def GetVelocityFieldDirection(self):
        r"""GetVelocityFieldDirection(self) -> itkMatrixD33"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_GetVelocityFieldDirection(self)

    def SetSplineOrder(self, _arg):
        r"""
        SetSplineOrder(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_SetSplineOrder(self, _arg)

    def GetSplineOrder(self):
        r"""GetSplineOrder(self) -> unsigned int"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_GetSplineOrder(self)
    __swig_destroy__ = _itkTimeVaryingBSplineVelocityFieldTransformPython.delete_itkTimeVaryingBSplineVelocityFieldTransformD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTimeVaryingBSplineVelocityFieldTransformD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTimeVaryingBSplineVelocityFieldTransformD2

        Create a new object of the class itkTimeVaryingBSplineVelocityFieldTransformD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTimeVaryingBSplineVelocityFieldTransformD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTimeVaryingBSplineVelocityFieldTransformD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTimeVaryingBSplineVelocityFieldTransformD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTimeVaryingBSplineVelocityFieldTransformD2 in _itkTimeVaryingBSplineVelocityFieldTransformPython:
_itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD2_swigregister(itkTimeVaryingBSplineVelocityFieldTransformD2)

def itkTimeVaryingBSplineVelocityFieldTransformD3_New():
    return itkTimeVaryingBSplineVelocityFieldTransformD3.New()

class itkTimeVaryingBSplineVelocityFieldTransformD3(itk.itkVelocityFieldTransformPython.itkVelocityFieldTransformD3):
    r"""Proxy of C++ itkTimeVaryingBSplineVelocityFieldTransformD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkTimeVaryingBSplineVelocityFieldTransformD3_Pointer"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkTimeVaryingBSplineVelocityFieldTransformD3_Pointer"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_Clone(self)

    def GetTimeVaryingVelocityFieldControlPointLattice(self):
        r"""GetTimeVaryingVelocityFieldControlPointLattice(self) -> itkImageVD34"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_GetTimeVaryingVelocityFieldControlPointLattice(self)

    def SetTimeVaryingVelocityFieldControlPointLattice(self, fieldLattice):
        r"""
        SetTimeVaryingVelocityFieldControlPointLattice(self, fieldLattice)

        Parameters
        ----------
        fieldLattice: itkImageVD34 *

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_SetTimeVaryingVelocityFieldControlPointLattice(self, fieldLattice)

    def UpdateTransformParameters(self, update, factor=1.):
        r"""
        UpdateTransformParameters(self, update, factor=1.)

        Parameters
        ----------
        update: itkArrayD const &
        factor: double

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_UpdateTransformParameters(self, update, factor)

    def SetVelocityFieldOrigin(self, _arg):
        r"""
        SetVelocityFieldOrigin(self, _arg)

        Parameters
        ----------
        _arg: itkPointD4

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_SetVelocityFieldOrigin(self, _arg)

    def GetVelocityFieldOrigin(self):
        r"""GetVelocityFieldOrigin(self) -> itkPointD4"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_GetVelocityFieldOrigin(self)

    def SetVelocityFieldSpacing(self, _arg):
        r"""
        SetVelocityFieldSpacing(self, _arg)

        Parameters
        ----------
        _arg: itkVectorD4

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_SetVelocityFieldSpacing(self, _arg)

    def GetVelocityFieldSpacing(self):
        r"""GetVelocityFieldSpacing(self) -> itkVectorD4"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_GetVelocityFieldSpacing(self)

    def SetVelocityFieldSize(self, _arg):
        r"""
        SetVelocityFieldSize(self, _arg)

        Parameters
        ----------
        _arg: itkSize4

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_SetVelocityFieldSize(self, _arg)

    def GetVelocityFieldSize(self):
        r"""GetVelocityFieldSize(self) -> itkSize4"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_GetVelocityFieldSize(self)

    def SetVelocityFieldDirection(self, _arg):
        r"""
        SetVelocityFieldDirection(self, _arg)

        Parameters
        ----------
        _arg: itkMatrixD44

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_SetVelocityFieldDirection(self, _arg)

    def GetVelocityFieldDirection(self):
        r"""GetVelocityFieldDirection(self) -> itkMatrixD44"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_GetVelocityFieldDirection(self)

    def SetSplineOrder(self, _arg):
        r"""
        SetSplineOrder(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_SetSplineOrder(self, _arg)

    def GetSplineOrder(self):
        r"""GetSplineOrder(self) -> unsigned int"""
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_GetSplineOrder(self)
    __swig_destroy__ = _itkTimeVaryingBSplineVelocityFieldTransformPython.delete_itkTimeVaryingBSplineVelocityFieldTransformD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkTimeVaryingBSplineVelocityFieldTransformD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkTimeVaryingBSplineVelocityFieldTransformD3

        Create a new object of the class itkTimeVaryingBSplineVelocityFieldTransformD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkTimeVaryingBSplineVelocityFieldTransformD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkTimeVaryingBSplineVelocityFieldTransformD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkTimeVaryingBSplineVelocityFieldTransformD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkTimeVaryingBSplineVelocityFieldTransformD3 in _itkTimeVaryingBSplineVelocityFieldTransformPython:
_itkTimeVaryingBSplineVelocityFieldTransformPython.itkTimeVaryingBSplineVelocityFieldTransformD3_swigregister(itkTimeVaryingBSplineVelocityFieldTransformD3)

